#############################################################################
#  Copyright (c) 2012 by Michael Fischer. All rights reserved.
#
#  Redistribution and use in source and binary forms, with or without 
#  modification, are permitted provided that the following conditions 
#  are met:
#  
#  1. Redistributions of source code must retain the above copyright 
#     notice, this list of conditions and the following disclaimer.
#  2. Redistributions in binary form must reproduce the above copyright
#     notice, this list of conditions and the following disclaimer in the 
#     documentation and/or other materials provided with the distribution.
#  3. Neither the name of the author nor the names of its contributors may 
#     be used to endorse or promote products derived from this software 
#     without specific prior written permission.
#
#  THIS SOFTWARE IS PROVIDED BY THE COPYRIGHT HOLDERS AND CONTRIBUTORS 
#  "AS IS" AND ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT 
#  LIMITED TO, THE IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS 
#  FOR A PARTICULAR PURPOSE ARE DISCLAIMED. IN NO EVENT SHALL 
#  THE COPYRIGHT OWNER OR CONTRIBUTORS BE LIABLE FOR ANY DIRECT, INDIRECT, 
#  INCIDENTAL, SPECIAL, EXEMPLARY, OR CONSEQUENTIAL DAMAGES (INCLUDING, 
#  BUT NOT LIMITED TO, PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES; LOSS 
#  OF USE, DATA, OR PROFITS; OR BUSINESS INTERRUPTION) HOWEVER CAUSED 
#  AND ON ANY THEORY OF LIABILITY, WHETHER IN CONTRACT, STRICT LIABILITY, 
#  OR TORT (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY OUT OF 
#  THE USE OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF 
#  SUCH DAMAGE.
#
#############################################################################
#  History:
#
#  12.02.2012  mifi  First Version, tested with an Altera DE1 board.
#                    This file based on the Altera file for UCOSII. 
#############################################################################

#
# chibios_systemh_generation.tcl
#
proc create_ch_frequency_macro {} {
    # Get BSP system timer name
    set timer_name [get_setting hal.sys_clk_timer]

    # Convert to upper-case
    set timer_name [string toupper $timer_name]

    #
    # Bail if not assigned
    #
    # If timer is assigned, add system.h macro. Should look like:
    #   "#define CH_FREQUENCY <timer name upper case>_TICKS_PER_SEC
    if {[string compare $timer_name "NONE"] == 0} {
        puts "ERROR: ChibiOS/RT system.h generation tcl script:"
        puts " --> HAL system timer not defined. ChibiOS/RT may not build!"
        puts " --> Set hal.sys_clk_timer to a timer device and then re-generate the BSP."
    } else {
        set tps_str _TICKS_PER_SEC
        set tps_setting $timer_name$tps_str

        # Add to system.h content for ChibiOS/RT
        add_systemh_line ChibiOS_v241 CH_FREQUENCY $tps_setting
    }
}

# Call procedure to generate CH_FREQUENCY macro
create_ch_frequency_macro

